
/*==============================================*\

  Vendredi 4 mai 2000

  Arash Habibi

  TestDessin2D.c

  Teste des fonctions de la librairie 
  libDessin2D. 

\*==============================================*/


#include <stdlib.h>
#include "Dessin2D.h"


//------------------------------------------------
//  Dessine n couples de gros points blancs placs 
//  au hasard sur une fenetre  fond rouge sombre 
// Ensuite la fonction relie les couples de 
// points par des segments jaunes. 
//------------------------------------------------

void _Test(image_t *image, int nb_points, int nb_segments)
{  
  int i, x, y, xdeb, ydeb, xfin, yfin; 

  // ---- Colorie le fond de l'image en -------
  // ---- rouge fonce (100,0,50) --------------

  D2D_SetColor(image, 100, 0, 50); 
  D2D_Clear(image); 

  // ---- Le dessin des nb_segments segments -----

  for(i=0; i<nb_segments; i++)
    {
      // les segments seront dessines en jaune
      D2D_SetColor(image, 255, 255, 0); 

      xdeb = (int)((image->largeur)*drand48()); 
      ydeb = (int)((image->hauteur)*drand48()); 

      xfin = (int)((image->largeur)*drand48()); 
      yfin = (int)((image->hauteur)*drand48()); 

      // dessine un segment entre le point 
      // (xdeb,ydeb) et le point (xfin,yfin)
      D2D_Line(image, xdeb, ydeb, xfin, yfin); 
    }

  // ---- Le dessin des nb_points points ------

  for(i=0; i<nb_points; i++)
    {
      // les points seront dessines en vert
      D2D_SetColor(image, 0, 255, 0); 

      x = (int)((image->largeur)*drand48()); 
      y = (int)((image->hauteur)*drand48()); 

      // On colorie le pixel et aussi quelques
      // voisins pour grossir le point 
      D2D_Plot(image, x,   y); 
      D2D_Plot(image, x+1, y);
      D2D_Plot(image, x,   y+1);
      D2D_Plot(image, x+1, y+1);
    }
}


//------------------------------------------------
//------------------------------------------------

void LectureParametres(int argc, char** argv, int *largeur, int *hauteur)
{
  if(argc!=3) 
    {
      fprintf(stderr,"\nUsage : %s <largeur> <hauteur>\n\n", argv[0]); 
      exit(1);
    }
  else
    {
      *largeur = atoi(argv[1]); 
      *hauteur = atoi(argv[2]); 
    }
}


//------------------------------------------------
//------------------------------------------------

int main(int argc, char **argv)
{
  int largeur, hauteur; /* largeur de la fenetre */
  image_t *image;
  
  // Pour recuperer les dimensions de l'image 
  // d'apres les arguments donnes au programme
  LectureParametres(argc, argv, &largeur, &hauteur); 

  // Ouvre un buffer image
  image = D2D_New(largeur, hauteur); 

  // Dessine 20 points et 10 segments de
  // droite places au hasard dans ce buffer. 
  _Test(image, 20, 10); 

  // Sauvegarde cette image dans le fichier resultat.ppm
  D2D_SaveImagePPM(image, "resultat.ppm", argv[0]); 


  // Ferme le buffer image et libere la memoire.
  D2D_Close(image);

  return 0; 
}









