
/*==============================================*\

  Mercredi 3 Fevrier 1999

  Arash Habibi

  Dessin2D.h

  Librairie permettant de dessiner point par point
  des fichiers image individuels au format ppm. 
  Les fichiers au format ppm peuvent etre visualises
  et transformes par le programme xv. Ces fonctions 
  ne permettent pas de faire des animations. 

\*==============================================*/

#ifndef DESSIN_2D_H_
#define DESSIN_2D_H_

#include <stdio.h>
#include <stdlib.h>

#include <time.h>
#include <pwd.h>
#include <sys/types.h>
#include <unistd.h>

typedef struct 
{
  unsigned char rouge, vert, bleu; 
} couleur_t; 

typedef struct
{
  int largeur, hauteur; 
  couleur_t couleur_courante; 
  unsigned char *image_buffer; 
}image_t; 

// image_buffer est un tableau unidimensionnel
// mais qui represente une image (bidimensionnelle)
// D'abord chaque pixel est represente par trois 
// unsigned char (rouge, vert, bleu) consecutifs. 
// Les trois entiers representent le pixel situe
// en bas a gauche de l'ecran, les suivants 
// representent les pixels sur la premiere ligne 
// en bas de l'image. Les elements suivants 
// representent les pixels qui se trouvent sur les 
// lignes superieurs et ainsi de suite. 

// Cree un objet de type image_t 
// et alloue le tableau image_buffer. 
extern image_t *D2D_New(int largeur, int hauteur); 

// Fixe la couleur courante a (rouge,vert,bleu)
// Tout ce qui est dessine apres l'appel de cette 
// fonction et jusqu'au prochain appel sera de 
// cette couleur. 
extern void D2D_SetColor(image_t *img, unsigned char rouge, unsigned char vert, unsigned char bleu); 

// Colorie toute l'image avec la couleur courante
extern void D2D_Clear     (image_t *img); 

// Colorie le pixel de coordonnees (x,y) 
// avec la couleur courante. 
extern void D2D_Plot      (image_t *img, int x, int y);

// Dessine un segment de droite entre le pixel (xdeb,ydeb) 
// et le pixel (xfin,yfin) avec la couleur courante. 
extern void D2D_Line      (image_t *img, int xdeb, int ydeb, int xfin, int yfin);

// Sauvegarde le contenu de img en format ppm dans 
// un fichier dont le nom est ImageFileName. 
// La chaine de caractere NomProg n'a aucune 
// influence sur l'essentiel du fonctionnement
// mais permet d'ecrire en commentaire dans le 
// fichier image, le nom du programme qui l'a 
// genere. NomProg peut valoir "". 
extern void D2D_SaveImagePPM(image_t *img, char *ImageFileName, char *NomProg);

// Libere la memoire occupee par img en liberant 
// aussi le buffer image de img. 
extern void D2D_Close(image_t *img); 

// Affiche a l'ecran les proprietes de img 
// n'affiche pas la couleur de tous les points. 
extern void D2D_CheckImage(image_t  img, char *commentaire); 

// Affiche a l'ecran les proprietes du pixel
// (x,y) de img. 
extern void D2D_CheckPixel(image_t  img, int x, int y, char *commentaire); 

#endif




